# geoca

[![image](https://img.shields.io/pypi/v/geoca.svg)](https://pypi.python.org/pypi/geoca)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

**A Python module for CA models based on geo-raster data**

- Free software: MIT License
- Documentation: [https://Haorui-Jiang.github.io/geoca](https://Haorui-Jiang.github.io/geoca)

## Features

- Read raster data from a file, convert the data into a Python list. 
- Create a raster template based on the input raster, and replace the data from list into the new raster. 
- Running CA models based on raster data to analyze population and other resource migration.

## File Template

- [cookiecutter-pypackage](): Cookiecutter template creating a Python package with mkdocs.

## Acknowledgement

Special thanks to [Dr. Qiusheng Wu](https://github.com/giswqs) from the University of Tennessee for his generous sharing. I have learned a great deal from [Dr. Wu&#39;s YouTube videos](https://youtube.com/playlist?list=PLAxJ4-o7ZoPcD-6wZ2xY5bXuu48Scu8kq&si=dq_x-xUJZvoflVqy), and with his guidance, I was able to develop geoca step by step. Once again, I express my deepest gratitude to Dr. Wu.
